use strict;
use warnings;
package Rubric::CLI::Command::commands;
# ABSTRACT: list the rubric commands
$Rubric::CLI::Command::commands::VERSION = '0.155';
use parent qw(App::Cmd::Command::commands);

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Rubric::CLI::Command::commands - list the rubric commands

=head1 VERSION

version 0.155

=head1 AUTHOR

Ricardo SIGNES <rjbs@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2004 by Ricardo SIGNES.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
